### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.9.1](https://github.com/nevermined-io/common-utils-py/compare/v0.9.0...v0.9.1)

> 24 January 2022

- new version [`#46`](https://github.com/nevermined-io/common-utils-py/pull/46)
- fix map [`#45`](https://github.com/nevermined-io/common-utils-py/pull/45)
- Adding v0.9.0 Changelog updates [`c2e77ff`](https://github.com/nevermined-io/common-utils-py/commit/c2e77ffb05196143bf620bdb5df8a006d64e399a)

#### [v0.9.0](https://github.com/nevermined-io/common-utils-py/compare/v0.8.0...v0.9.0)

> 21 December 2021

- Update contracts lib py [`#44`](https://github.com/nevermined-io/common-utils-py/pull/44)
- Added metadata methods to store and retrieve service agreements [`#43`](https://github.com/nevermined-io/common-utils-py/pull/43)
- Adding v0.8.0 Changelog updates [`2a012d5`](https://github.com/nevermined-io/common-utils-py/commit/2a012d58e4a5dd0f0cc32ee8c91fe301c7dcf159)

#### [v0.8.0](https://github.com/nevermined-io/common-utils-py/compare/v0.7.10...v0.8.0)

> 10 December 2021

- Add support for contracts 1.3.0 on mumbai [`#42`](https://github.com/nevermined-io/common-utils-py/pull/42)
- Adding v0.7.10 Changelog updates [`7106e3b`](https://github.com/nevermined-io/common-utils-py/commit/7106e3b10668df6493cadfde2bdd50bb056c2caf)

#### [v0.7.10](https://github.com/nevermined-io/common-utils-py/compare/v0.7.9...v0.7.10)

> 2 December 2021

- Fixing the prover [`#41`](https://github.com/nevermined-io/common-utils-py/pull/41)
- Adding v0.7.9 Changelog updates [`6da5da6`](https://github.com/nevermined-io/common-utils-py/commit/6da5da6b9c798242d21605f6970f9ca6f30651c6)
- choose correct lib on runtime [`a0e2f2e`](https://github.com/nevermined-io/common-utils-py/commit/a0e2f2e35502ed0093b28d597cf4de1387a6b395)
- Bump version: 0.7.9 → 0.7.10 [`5825079`](https://github.com/nevermined-io/common-utils-py/commit/582507904fa7b069fe872cec7f6baf45354c521d)

#### [v0.7.9](https://github.com/nevermined-io/common-utils-py/compare/v0.7.8...v0.7.9)

> 1 December 2021

- Use ServiceAgreement instead of Service for NFT_SALES [`#39`](https://github.com/nevermined-io/common-utils-py/pull/39)
- Skip test that causes the python runtime to crash [`7fb3cb2`](https://github.com/nevermined-io/common-utils-py/commit/7fb3cb2cb903a0a03f50c43afc02306ef3b7edb9)
- Update to latest version of contracts-lib-py [`162081e`](https://github.com/nevermined-io/common-utils-py/commit/162081e72704e44dbfda5995723b98aa53f467be)

#### [v0.7.8](https://github.com/nevermined-io/common-utils-py/compare/v0.7.7...v0.7.8)

> 2 November 2021

- Adding v0.7.8 Changelog updates [`#37`](https://github.com/nevermined-io/common-utils-py/pull/37)
- EDDSA signature for babyjub [`#36`](https://github.com/nevermined-io/common-utils-py/pull/36)
- Make rapidsnark optional [`#35`](https://github.com/nevermined-io/common-utils-py/pull/35)
- add signature verification for babyjub [`4232880`](https://github.com/nevermined-io/common-utils-py/commit/42328804592e0f2def6d812d26b6b8030be483f7)
- trying to make rapidsnark optional [`006ff5e`](https://github.com/nevermined-io/common-utils-py/commit/006ff5e9dfa8abee7a6b1cc4f8d80b7a0962f6e4)
- working ... [`2a22fc3`](https://github.com/nevermined-io/common-utils-py/commit/2a22fc39881d63dde6c60536346712f61b4ac1ce)

#### [v0.7.7](https://github.com/nevermined-io/common-utils-py/compare/v0.7.6...v0.7.7)

> 19 October 2021

- Data transfer changes [`#33`](https://github.com/nevermined-io/common-utils-py/pull/33)
- some crypto operations [`4992d39`](https://github.com/nevermined-io/common-utils-py/commit/4992d3924f1d6f024225b0ab7f41f5838cb90132)
- trying to add stuff needed by key transfer proof [`3aceb67`](https://github.com/nevermined-io/common-utils-py/commit/3aceb67c8aab814eb00fb750378e0de017c23ab1)
- some crypto operations [`974c97f`](https://github.com/nevermined-io/common-utils-py/commit/974c97fe3aab5e12fee3c460e4d69dc3c714e015)

#### [v0.7.6](https://github.com/nevermined-io/common-utils-py/compare/v0.7.5...v0.7.6)

> 7 October 2021

- Unify templates with sdk-js [`#34`](https://github.com/nevermined-io/common-utils-py/pull/34)
- Adding v0.7.5 Changelog updates [`6a79ac3`](https://github.com/nevermined-io/common-utils-py/commit/6a79ac333f038f94bfb4784bab809f5575d404a1)
- Match escrowPayment contractName with js sdk [`f2e20a6`](https://github.com/nevermined-io/common-utils-py/commit/f2e20a6982a37179075a1e1dd11c636551b32bda)
- bump version [`054a83f`](https://github.com/nevermined-io/common-utils-py/commit/054a83f8dc5c4b1e11cc539a973a8e70e20c8ab2)

#### [v0.7.5](https://github.com/nevermined-io/common-utils-py/compare/v0.7.4...v0.7.5)

> 7 September 2021

- Adds the _nftHolder param to the TransferNFTCondition in the ddo [`#32`](https://github.com/nevermined-io/common-utils-py/pull/32)
- Adding v0.7.4 Changelog updates [`5f2b4d8`](https://github.com/nevermined-io/common-utils-py/commit/5f2b4d82ccf89e5aeafff1d9ed6f526c34b32daa)

#### [v0.7.4](https://github.com/nevermined-io/common-utils-py/compare/v0.7.3...v0.7.4)

> 7 September 2021

- Updating the latest contracts version [`#31`](https://github.com/nevermined-io/common-utils-py/pull/31)
- Add _nftHolder param to TransferNFTCondition [`55f91dc`](https://github.com/nevermined-io/common-utils-py/commit/55f91dc63ebb76fb67a449f5ea8411e7c6e58b3e)
- Adding v0.7.3 Changelog updates [`6b02a90`](https://github.com/nevermined-io/common-utils-py/commit/6b02a90cbda62e66203baf804cc8bd4619d4a777)
- Use new version of contracts-lib-py [`7bbd2f7`](https://github.com/nevermined-io/common-utils-py/commit/7bbd2f7ab8ebcaa2319725ca6b77b9050b1e711a)

#### [v0.7.3](https://github.com/nevermined-io/common-utils-py/compare/v0.7.2...v0.7.3)

> 30 July 2021

- Feature/nft721 [`#30`](https://github.com/nevermined-io/common-utils-py/pull/30)
- Update nevermined tools invocation in the CI [`76b11dd`](https://github.com/nevermined-io/common-utils-py/commit/76b11ddc9361312aab4db87ad906d20a38c8f51b)
- Added service definition for nft721 [`5991d5e`](https://github.com/nevermined-io/common-utils-py/commit/5991d5e5be0e66602e3acf7a9b94509a887f3be5)
- Don't run the compute stack on the CI [`9bd47ce`](https://github.com/nevermined-io/common-utils-py/commit/9bd47ce12cf32c7c4d302ea1330ab79e0b858d20)

#### [v0.7.2](https://github.com/nevermined-io/common-utils-py/compare/v0.7.1...v0.7.2)

> 15 July 2021

- using last contract version [`#29`](https://github.com/nevermined-io/common-utils-py/pull/29)
- Adding v0.7.1 Changelog updates [`380fc22`](https://github.com/nevermined-io/common-utils-py/commit/380fc22089650bbfbc2eed76e1ea2a5265b72ba5)

#### [v0.7.1](https://github.com/nevermined-io/common-utils-py/compare/v0.7.0...v0.7.1)

> 20 May 2021

- Adding support methods to facilitate NFT flow [`#28`](https://github.com/nevermined-io/common-utils-py/pull/28)
- Bump rsa from 4.1 to 4.7 [`#27`](https://github.com/nevermined-io/common-utils-py/pull/27)
- Adapting to new contracts release (rc8) [`0ecb65f`](https://github.com/nevermined-io/common-utils-py/commit/0ecb65f8157443ed47c5d5b2a7c952ade542c62b)
- using `add_0x_prefix` method instead of direct concatenation of strings [`d5db422`](https://github.com/nevermined-io/common-utils-py/commit/d5db422a863bf5a3c4406f2f1861104346069d81)
- testing [`7e26f6a`](https://github.com/nevermined-io/common-utils-py/commit/7e26f6a046b23b51392a0fc52283b1fb1c6c0c3f)

#### [v0.7.0](https://github.com/nevermined-io/common-utils-py/compare/v0.6.2...v0.7.0)

> 21 April 2021

- Implementing new token payment methods [`#26`](https://github.com/nevermined-io/common-utils-py/pull/26)
- Adding v0.6.2 Changelog updates [`a00298f`](https://github.com/nevermined-io/common-utils-py/commit/a00298fe395abe8e19704119cffd564f476404c1)
- removing `--no-secret-store` flag in CI because is not available anymore, SS is disabled by default [`1462d5c`](https://github.com/nevermined-io/common-utils-py/commit/1462d5cf3e921285f54eeb7322b7a1672f5610b8)

#### [v0.6.2](https://github.com/nevermined-io/common-utils-py/compare/v0.6.1...v0.6.2)

> 15 April 2021

- Adapting to new nftAccess condition [`#25`](https://github.com/nevermined-io/common-utils-py/pull/25)
- Adding v0.6.1 Changelog updates [`8e5b0c8`](https://github.com/nevermined-io/common-utils-py/commit/8e5b0c8ab2d57d2e58b37340fe655945ea013cab)

#### [v0.6.1](https://github.com/nevermined-io/common-utils-py/compare/v0.6.0...v0.6.1)

> 14 April 2021

- NFT end2end implementation [`#24`](https://github.com/nevermined-io/common-utils-py/pull/24)
- Adding v0.6.0 Changelog updates [`d42fd50`](https://github.com/nevermined-io/common-utils-py/commit/d42fd50a3ea8b972aa062e668d48e48393848423)

#### [v0.6.0](https://github.com/nevermined-io/common-utils-py/compare/v0.5.0...v0.6.0)

> 13 April 2021

- NFTs implementation [`#23`](https://github.com/nevermined-io/common-utils-py/pull/23)
- Bump rsa from 4.0 to 4.1 [`#21`](https://github.com/nevermined-io/common-utils-py/pull/21)
- Adding v0.5.0 Changelog updates [`6b0caac`](https://github.com/nevermined-io/common-utils-py/commit/6b0caac6069d8ebe025ca7bf79047d08c629c9e7)
- Fixing service factory with new templates [`5ee2371`](https://github.com/nevermined-io/common-utils-py/commit/5ee23715407d98066719a913d1d5455ce81d0fa8)
- fixing comment [`37704d4`](https://github.com/nevermined-io/common-utils-py/commit/37704d4ebb70528d3a0879c23c718db16b7bb782)

#### [v0.5.0](https://github.com/nevermined-io/common-utils-py/compare/v0.4.6...v0.5.0)

> 30 March 2021

- Adapting to new contracts v1.0 [`#22`](https://github.com/nevermined-io/common-utils-py/pull/22)
- Adding v0.4.6 Changelog updates [`cd12c06`](https://github.com/nevermined-io/common-utils-py/commit/cd12c060dea7b77e58919cdc8286730e63f12029)

#### [v0.4.6](https://github.com/nevermined-io/common-utils-py/compare/v0.4.5...v0.4.6)

> 8 February 2021

- Because elastic the reward types in the ddo need to be a string [`#20`](https://github.com/nevermined-io/common-utils-py/pull/20)
- Fixing error fulfilling gateway escrow reward [`#19`](https://github.com/nevermined-io/common-utils-py/pull/19)

#### [v0.4.5](https://github.com/nevermined-io/common-utils-py/compare/v0.4.4...v0.4.5)

> 5 February 2021

- tests [`fd848a1`](https://github.com/nevermined-io/common-utils-py/commit/fd848a1895e202201d1bb6224f8fb3ca2ffb74e4)
- Fixing error fulfilling gateway escrow reward [`88de48e`](https://github.com/nevermined-io/common-utils-py/commit/88de48ea392a6b90ba733dda5230a9ba4b25dbde)
- fixing agreement templates [`99be256`](https://github.com/nevermined-io/common-utils-py/commit/99be256a5c1995567cd8ab5e278cbe6109868107)

#### [v0.4.4](https://github.com/nevermined-io/common-utils-py/compare/v0.4.3...v0.4.4)

> 2 February 2021

- bumping to last version of contracts v0.6.2 [`56dc62a`](https://github.com/nevermined-io/common-utils-py/commit/56dc62ac7c6db291882de48b885abe7d58c68273)
- Adding v0.4.3 Changelog updates [`462eb13`](https://github.com/nevermined-io/common-utils-py/commit/462eb1374270ea2893e377a95c4a2b508bc62062)
- using latest version of components in CI [`f6d1418`](https://github.com/nevermined-io/common-utils-py/commit/f6d1418daf113db807a252bc9050600936b45022)

#### [v0.4.3](https://github.com/nevermined-io/common-utils-py/compare/v0.4.2...v0.4.3)

> 11 January 2021

- Added a new optional field to jwt grant [`#18`](https://github.com/nevermined-io/common-utils-py/pull/18)
- fix tests [`7cf1edb`](https://github.com/nevermined-io/common-utils-py/commit/7cf1edb79267495dd133c545e21b7cd6fadfd9fd)
- Bump version: 0.4.2 → 0.4.3 [`7cdc5ad`](https://github.com/nevermined-io/common-utils-py/commit/7cdc5ad9eb632a99a06f1c2682280a11e994525a)
- Updated CI [`da324bd`](https://github.com/nevermined-io/common-utils-py/commit/da324bdfc634ba9d8a9ed4d0a42a1c907195d422)

#### [v0.4.2](https://github.com/nevermined-io/common-utils-py/compare/v0.4.1...v0.4.2)

> 4 December 2020

- Feature/add bytes converter [`#17`](https://github.com/nevermined-io/common-utils-py/pull/17)
- add did converter [`c290a5b`](https://github.com/nevermined-io/common-utils-py/commit/c290a5b4e79d695a6ffae77c9e309dd158d11cdd)
- Adding v0.4.1 Changelog updates [`bf37fa6`](https://github.com/nevermined-io/common-utils-py/commit/bf37fa64251e2bc85ad3ff4da0dc3e0ea5ac4028)
- Bump version: 0.4.1 → 0.4.2 [`a9cd60e`](https://github.com/nevermined-io/common-utils-py/commit/a9cd60ef54e7d8d9913f5bf50a7293b99a856b27)

#### [v0.4.1](https://github.com/nevermined-io/common-utils-py/compare/v0.4.0...v0.4.1)

> 2 December 2020

- Fix/authlib fork [`#16`](https://github.com/nevermined-io/common-utils-py/pull/16)
- Adding v0.4.0 Changelog updates [`3300981`](https://github.com/nevermined-io/common-utils-py/commit/3300981aaedde5cb3f501f44a14e4a02103645aa)
- Bump version: 0.4.0 → 0.4.1 [`c72342a`](https://github.com/nevermined-io/common-utils-py/commit/c72342a27783bb7d0134717dac8768f867e348fb)
- Use fork of authlib [`d052177`](https://github.com/nevermined-io/common-utils-py/commit/d05217726c2aa15649eada90d2bfa7ebc5310b45)

#### [v0.4.0](https://github.com/nevermined-io/common-utils-py/compare/v0.3.0...v0.4.0)

> 2 December 2020

- Added some jwt utils [`#15`](https://github.com/nevermined-io/common-utils-py/pull/15)
- Added jwt utilites to be used by the sdk and gateway [`7bd50cc`](https://github.com/nevermined-io/common-utils-py/commit/7bd50cc2c167b8549d1ed59e770dcaba5f9162e6)
- Adding v0.3.0 Changelog updates [`efa6d30`](https://github.com/nevermined-io/common-utils-py/commit/efa6d3034105f8600f6f80149d30ec7aaadac3fe)
- Bump version: 0.3.0 → 0.4.0 [`66e9218`](https://github.com/nevermined-io/common-utils-py/commit/66e9218ca7d2c09fd98b35543cc9eda75aa8a1b3)

#### [v0.3.0](https://github.com/nevermined-io/common-utils-py/compare/v0.2.8...v0.3.0)

> 6 November 2020

- renaming org [`374bc79`](https://github.com/nevermined-io/common-utils-py/commit/374bc7961b8a54e3ec0f408205d3dd73f9816028)
- fixing url tests [`b3123f2`](https://github.com/nevermined-io/common-utils-py/commit/b3123f2bc614c9a56235879f61306bc9256e3280)
- changing contrats-lib-py version [`3d2da26`](https://github.com/nevermined-io/common-utils-py/commit/3d2da2659f70fd6b468502158536ceda1473c870)

#### [v0.2.8](https://github.com/nevermined-io/common-utils-py/compare/v0.2.7...v0.2.8)

> 14 May 2020

- Fix/decryption issues [`#14`](https://github.com/nevermined-io/common-utils-py/pull/14)
- Fix error in aes decryption [`cd650d1`](https://github.com/nevermined-io/common-utils-py/commit/cd650d152cc82c8a9e86dbe8f2353aefe54bec6c)
- Bump version: 0.2.7 → 0.2.8 [`bba3f1e`](https://github.com/nevermined-io/common-utils-py/commit/bba3f1edb11716f122f7564cb2d386cc0414caa9)
- Update changelog [`0df110f`](https://github.com/nevermined-io/common-utils-py/commit/0df110f13af96826741102346ffa26c29475dac6)

#### [v0.2.7](https://github.com/nevermined-io/common-utils-py/compare/v0.2.5...v0.2.7)

> 13 May 2020

- Fixing rsa flow [`#13`](https://github.com/nevermined-io/common-utils-py/pull/13)
- fixing rsa flow [`53a4034`](https://github.com/nevermined-io/common-utils-py/commit/53a4034ed03d78de2236b9d416ec4e59aba380f2)
- adding v0.2.6 changelog [`b841bb9`](https://github.com/nevermined-io/common-utils-py/commit/b841bb9afc73cc5b5027806926565598caaf2db5)
- Bump version: 0.2.6 → 0.2.7 [`88f2bd1`](https://github.com/nevermined-io/common-utils-py/commit/88f2bd15dcf651b31db0b4aac825cc179c4d96b8)

#### [v0.2.5](https://github.com/nevermined-io/common-utils-py/compare/v0.2.4...v0.2.5)

> 13 May 2020

- Adding AES encryption & decryption + RSA support for long messages [`#12`](https://github.com/nevermined-io/common-utils-py/pull/12)
- adding AES encryption & decryption + RSA support for long messages [`46e6904`](https://github.com/nevermined-io/common-utils-py/commit/46e690400fab2215a60d299d8f2197b27da144ed)
- Bump version: 0.2.4 → 0.2.5 [`173c55a`](https://github.com/nevermined-io/common-utils-py/commit/173c55a88d55765e1a3c7f8454114c5a50de3e9c)
- removing comments [`2f39adb`](https://github.com/nevermined-io/common-utils-py/commit/2f39adbf5997cb6bf021017832b7972b618deff5)

#### [v0.2.4](https://github.com/nevermined-io/common-utils-py/compare/v0.2.3...v0.2.4)

> 12 May 2020

- Feature/service factory authorization [`#11`](https://github.com/nevermined-io/common-utils-py/pull/11)
- Udpate service factory to work with the same structure in theauthorization [`2861b66`](https://github.com/nevermined-io/common-utils-py/commit/2861b661fafe2ae31ca3edf7f2c536e6a2fc5332)
- Update exception names [`d404a33`](https://github.com/nevermined-io/common-utils-py/commit/d404a331abbdb65cad7d7e9def6720ae837b68a6)
- Bump version: 0.2.3 → 0.2.4 [`1d59a9a`](https://github.com/nevermined-io/common-utils-py/commit/1d59a9a81137c9f027d20d753875c48bc46ff3b7)

#### [v0.2.3](https://github.com/nevermined-io/common-utils-py/compare/v0.2.2...v0.2.3)

> 12 May 2020

- Adding utility functions to encrypt/descrypt [`#10`](https://github.com/nevermined-io/common-utils-py/pull/10)
- Implements #9 [`f1e0c95`](https://github.com/nevermined-io/common-utils-py/commit/f1e0c9527953779b191671a9b12d5d2045b53f20)
- Bump version: 0.2.2 → 0.2.3 [`01964b8`](https://github.com/nevermined-io/common-utils-py/commit/01964b87f61dbab5553cb7ff7cadd03529e39224)

#### [v0.2.2](https://github.com/nevermined-io/common-utils-py/compare/v0.2.1...v0.2.2)

> 7 May 2020

- Support to additional DDO auth services [`#8`](https://github.com/nevermined-io/common-utils-py/pull/8)
- Adding support to different authorization services in the DDO, implements #7 [`162ac82`](https://github.com/nevermined-io/common-utils-py/commit/162ac8269df6cf79b97781a8c3157940e518618a)
- Bump version: 0.2.1 → 0.2.2 [`a1cea5d`](https://github.com/nevermined-io/common-utils-py/commit/a1cea5d0c74ccb0aff74e783854c37cfc72f29eb)

#### [v0.2.1](https://github.com/nevermined-io/common-utils-py/compare/v0.2.0...v0.2.1)

> 6 May 2020

- Upgrade web3py version used in testing [`#6`](https://github.com/nevermined-io/common-utils-py/pull/6)
- Bump version: 0.2.0 → 0.2.1 [`b1bd62d`](https://github.com/nevermined-io/common-utils-py/commit/b1bd62d46b9d5193ad9ece551ed414a5209b6d83)
- Update Changelog [`66ecd56`](https://github.com/nevermined-io/common-utils-py/commit/66ecd5606ca0535004e5d020f2cba395bd8a990e)
- Update codeowners [`23d6c2b`](https://github.com/nevermined-io/common-utils-py/commit/23d6c2bc35036318ae4bba501bf46a7719d4d5da)

#### [v0.2.0](https://github.com/nevermined-io/common-utils-py/compare/v0.1.3...v0.2.0)

> 29 April 2020

- Feature/update names [`#5`](https://github.com/nevermined-io/common-utils-py/pull/5)
- Update names [`772534e`](https://github.com/nevermined-io/common-utils-py/commit/772534ed8cf3362bea9aaf60486db2fed24d734b)
- Bump version: 0.1.3 → 0.2.0 [`701682f`](https://github.com/nevermined-io/common-utils-py/commit/701682fc71f7de0d6bb92285113cd7d7b68086ae)
- Update command in workflow [`a103e44`](https://github.com/nevermined-io/common-utils-py/commit/a103e4470516f9e85367eb4221b960f03898b090)

#### [v0.1.3](https://github.com/nevermined-io/common-utils-py/compare/v0.1.2...v0.1.3)

> 28 April 2020

- Use ddos from nevermind-docs [`#3`](https://github.com/nevermined-io/common-utils-py/pull/3)
- Bump version: 0.1.2 → 0.1.3 [`d8bf126`](https://github.com/nevermined-io/common-utils-py/commit/d8bf126fef29596d6d3a9e7cdbb42424d335cea5)

#### [v0.1.2](https://github.com/nevermined-io/common-utils-py/compare/v0.1.1...v0.1.2)

> 24 April 2020

- Update licenses and templates [`#2`](https://github.com/nevermined-io/common-utils-py/pull/2)
- Bump version: 0.1.1 → 0.1.2 [`dc1b3da`](https://github.com/nevermined-io/common-utils-py/commit/dc1b3daea146e1c3d0b7f713daece96abb7e3710)
- Update workflow for release [`788fe18`](https://github.com/nevermined-io/common-utils-py/commit/788fe18c0f08a3546a7d78f6cc304a15c9ed9220)
- Let space [`814c00d`](https://github.com/nevermined-io/common-utils-py/commit/814c00d4a91d174c6bf289323c613fbd39ba3d4e)

#### [v0.1.1](https://github.com/nevermined-io/common-utils-py/compare/v0.1.0...v0.1.1)

> 23 April 2020

- Point to metadata instead of aquarius [`#1`](https://github.com/nevermined-io/common-utils-py/pull/1)
- Bump version: 0.1.0 → 0.1.1 [`3b75be5`](https://github.com/nevermined-io/common-utils-py/commit/3b75be581f8cdd9741fbff0b7d2224ebf5a165c5)
- Modify readme [`b457675`](https://github.com/nevermined-io/common-utils-py/commit/b45767584cebd9255e065ff3d5858169b65e8849)

#### v0.1.0

> 22 April 2020

- First commit [`132caf8`](https://github.com/nevermined-io/common-utils-py/commit/132caf86682d9534a463438a62a72a9348e5c48b)
- Update common utils to old version 0.2.7 [`3240fe8`](https://github.com/nevermined-io/common-utils-py/commit/3240fe87c0bf4554ea9f5887a5c22703a8142754)
- Update failing test [`03d710d`](https://github.com/nevermined-io/common-utils-py/commit/03d710d566647e0739b8ded997b1699db9c2b46f)
